@@ -18,7 +18,7 @@ use File::chdir;
 
 extends 'App::VTide::Command';
 
-our $VERSION = version->new('0.0.8');
+our $VERSION = version->new('0.1.0');
 our $NAME    = 'run';
 our $OPTIONS = [
     'name|n=s',
@@ -69,9 +69,9 @@ sub run {
         # run any hooks for run_running
         $self->hooks->run('run_running', \@cmd);
 
-        if ( $params->{headding} ) {
-            # show terminal headding if desired
-            print $params->{headding}, "\n";
+        if ( $params->{heading} ) {
+            # show terminal heading if desired
+            print $params->{heading}, "\n";
         }
 
         # start the terminal
@@ -316,7 +316,7 @@ App::VTide::Command::Run - Run a terminal command
 
 =head1 VERSION
 
-This documentation refers to App::VTide::Command::Run version 0.0.8
+This documentation refers to App::VTide::Command::Run version 0.1.0
 
 =head1 SYNOPSIS
 
