@@ -17,7 +17,7 @@ use YAML::Syck;
 
 extends 'App::VTide::Command';
 
-our $VERSION = version->new('0.0.8');
+our $VERSION = version->new('0.1.0');
 our $NAME    = 'start';
 our $OPTIONS = [
     'windows|w=i',
@@ -39,9 +39,31 @@ sub run {
 
     $self->hooks->run('start_pre', $name, $dir);
 
+    $self->ctags();
+
     return $self->tmux( $name );
 }
 
+sub ctags {
+    my ( $self ) = @_;
+    my $ctags = path('/usr', 'bin', 'ctags');
+
+    return if !$self->config->get->{start}{ctags} || !-x $ctags;
+
+    my @cmd = ($ctags, $self->config->get->{start}{ctags});
+
+    for my $exclude (@{ $self->config->get->{start}{"ctags-exclude"} }) {
+        if ( $self->config->get->{start}{"ctags-excludes"}{$exclude} ) {
+            push @cmd, map {"--exclude=$_"} @{ $self->config->get->{start}{"ctags-excludes"}{$exclude} };
+        }
+        else {
+            push @cmd, "--exclude=$exclude";
+        }
+    }
+
+    system @cmd;
+}
+
 sub tmux {
     my ( $self, $name ) = @_;
 
@@ -128,7 +150,7 @@ App::VTide::Command::Start - Start a session
 
 =head1 VERSION
 
-This documentation refers to App::VTide::Command::Start version 0.0.8
+This documentation refers to App::VTide::Command::Start version 0.1.0
 
 =head1 SYNOPSIS
 
@@ -160,6 +182,10 @@ configuration in the current directory.
 
 Starts the tmux session running a C<vtide run> command in each terminal
 
+=head2 C<ctags ()>
+
+Runs the ctags command if the config option I<ctags> in the I<start> group is set
+
 =head2 C<tmux ( $name )>
 
 Run a tmux session with the name C<$name>
@@ -214,4 +240,4 @@ distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
 PARTICULAR PURPOSE.
 
-=cut
+ =cut
